# Simple Mailer
A simple Python mailer script that's suitable for Namecheap Shared Hosting.

[![Build Status](https://travis-ci.com/zedr/simple-namecheap-mailer.svg?branch=master)](https://travis-ci.com/zedr/simple-namecheap-mailer)
